// -*-c++-*-
//===========================================================
//=     University of Illinois at Urbana/Champaign          =
//=     Department of Computer Science                      =
//=     Dr. Dan Roth - Cognitive Computation Group          =
//=                                                         =
//=  Project: Snow                                          =
//=                                                         =
//=   Module: Winnow.h                                      =
//=  Version: 2.1                                           =
//=  Authors: Jeff Rosen and Andrew Carlson                 =
//=     Date: xx/xx/98                                      = 
//=                                                         =
//= Comments:                                               =
//===========================================================

#ifndef __WINNOW_H__
#define __WINNOW_H__

#include "LearningAlgorithm.h"
#include "TargetIdSet.h"

class Winnow : public LearningAlgorithm
{
public:
    Winnow( double alpha = 2.0,
            double beta = 0.50,
            double threshold = 1.0,
            double defaultWeight = 0.05 );

    bool PresentExample( Target& tar, Example& ex );
    void TrainingComplete( Target& tar );
    void Discard( Target& tar );

    // Updates the target based on the example and the Winnow parameters
    void Update( Target& tar, Example& ex );

    void SetTargetActivation( Target& tar, Example& ex );
    double ReturnNormalizedActivation( Target& tar);

    void Show( ostream& out );
    
    void Read( ifstream& in );
    void Write( ofstream& out );
    
private:
    double  alpha;
    double  beta;
};

inline Winnow::Winnow( double al, double be, double th, double dw ) :
        LearningAlgorithm(th, dw),
        alpha(al),
        beta(be)
{
}

inline void Winnow::TrainingComplete( Target& tar )
{
}

#endif






